@@ -33,8 +33,6 @@
 static char rcsid[] = "$XConsortium: WmCDecor.c /main/7 1996/06/20 09:38:16 rswiston $"
 #endif
 #endif
-/*
- * (c) Copyright 1987,1988,1989,1990,1991,1993 HEWLETT-PACKARD COMPANY */
 
 /*
  * Included Files:
@@ -567,9 +565,9 @@ void GenerateFrameDisplayLists (ClientData *pcd)
     int insideBevel, inset, diffBevel;
     unsigned int nTitleBevel, sTitleBevel, eTitleBevel, wTitleBevel;
     unsigned int meTitleBevel, inWidth;
-    int x, y, xAdj, yAdj;
+    int x, y, xAdj = 0, yAdj = 0;
     unsigned int width, height;
-    RList *prlTop, *prlBot;
+    RList *prlTop = NULL, *prlBot = NULL;
 
     int jX, jY;
     unsigned int jW, jH;
