@@ -33,12 +33,6 @@
 static char rcsid[] = "$TOG: WmInitWs.c /main/18 1999/09/20 15:18:22 mgreess $"
 #endif
 #endif
-/*
- * (c) Copyright 1987, 1988, 1989, 1990, 1993, 1994 HEWLETT-PACKARD COMPANY 
- * (c) Copyright 1993, 1994 International Business Machines Corp.
- * (c) Copyright 1993, 1994 Sun Microsystems, Inc.
- * (c) Copyright 1993, 1994 Novell, Inc.
- */
 
 /*
  * Included Files:
@@ -134,6 +128,7 @@ typedef struct
 #include <stdlib.h>
 #endif /* WSM */
 #include "WmXSMP.h"
+#include "Xm/VirtKeysI.h"
 
 /*
  * Function Declarations:
@@ -271,7 +266,7 @@ BuildLockMaskSequence(void)
 	 * funny because we skip the case of all the
 	 * bits cleared.
 	 */
-	run = (0x1 << bit-1);	/* number of consecutive masks to set
+	run = (0x1 << (bit-1));	/* number of consecutive masks to set
 				   bits in */
 	bit_on = False;		/* are we setting bits or not? */
 
