@@ -20,9 +20,6 @@
  * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
  * Floor, Boston, MA 02110-1301 USA
 */ 
-/* 
- * HISTORY
-*/ 
 #ifdef REV_INFO
 #ifndef lint
 static char rcsid[] = "$TOG: UilLstMac.c /main/15 1997/03/12 15:21:48 dbl $"
@@ -34,9 +31,6 @@ static char rcsid[] = "$TOG: UilLstMac.c /main/15 1997/03/12 15:21:48 dbl $"
 #endif
 
 
-/*
-*  (c) Copyright 1989, 1990, DIGITAL EQUIPMENT CORPORATION, MAYNARD, MASS. */
-
 /*
 **++
 **  FACILITY:
@@ -396,7 +390,7 @@ src_source_record_type	*az_src_rec;
 {
 
     char			buffer [132], * ptr;
-    int				child_index;
+    int				child_index = 0;
 
     while ( ! off_stack_empty ) {
 
