@@ -20,9 +20,6 @@
  * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
  * Floor, Boston, MA 02110-1301 USA
 */ 
-/* 
- * HISTORY
-*/ 
 #ifdef REV_INFO
 #ifndef lint
 static char rcsid[] = "$TOG: UilSrcSrc.c /main/13 1997/03/12 15:21:40 dbl $"
@@ -34,9 +31,6 @@ static char rcsid[] = "$TOG: UilSrcSrc.c /main/13 1997/03/12 15:21:40 dbl $"
 #endif
 
 
-/*
-*  (c) Copyright 1989, 1990, DIGITAL EQUIPMENT CORPORATION, MAYNARD, MASS. */
-
 /*
 **++
 **  FACILITY:
@@ -474,7 +468,7 @@ src_get_source_line(void)
     /* Find the current fcb */
 
     az_fcb = src_az_source_file_table
-		[ src_az_current_source_buffer->b_file_number ];
+		[ (int)src_az_current_source_buffer->b_file_number ];
 
     /* Read the next record */
 
