@@ -1012,6 +1012,10 @@ PackWinData(Display *dpy, int screen_num, MessageData data,
 		    data = PackCARD32(data, (CARD32) this_data->data.value);
 		    break;			
 		}
+		break;
+	    case WSM_NONE:
+	        /* Not handled case */
+	        break;
 	    }
 
 	    /*
