@@ -39,6 +39,24 @@
 #include <pixmaps/porsche.xpm>
 #include <pixmaps/stopsign.xpm>
 
+/**************************************************************
+External functions
+**************************************************************/
+#ifdef NeedFunctionPrototypes
+#define ARGLIST(p)	(
+#define ARG(a, b)	a b,
+#define GRA(a, b)	a b)
+#else
+#define ARGLIST(p)	p
+#define ARG(a, b)	a b;
+#define GRA(a, b)	a b;
+#endif
+extern Pixmap XPM_PIXMAP
+ARGLIST((w, pixmapName))
+ARG(Widget, w)
+GRA(char **, pixmapName);
+
+
 /**************************************************************
  *		STATIC FUNCTION DECLARATIONS
  **************************************************************/
