@@ -20,16 +20,11 @@
  * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
  * Floor, Boston, MA 02110-1301 USA
  */ 
-/* 
- * HISTORY
-*/ 
 #ifdef REV_INFO
 #ifndef lint
 static char rcsid[] = "$TOG: CascadeBG.c /main/28 1999/02/01 18:47:11 mgreess $"
 #endif
 #endif
-/* (c) Copyright 1989, DIGITAL EQUIPMENT CORPORATION, MAYNARD, MASS. */
-/* (c) Copyright 1987, 1988, 1989, 1990, 1991, 1992 HEWLETT-PACKARD COMPANY */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -80,6 +75,7 @@ static char rcsid[] = "$TOG: CascadeBG.c /main/28 1999/02/01 18:47:11 mgreess $"
 #define WRONGSUBMENU	_XmMMsgCascadeB_0001
 #define WRONGMAPDELAY	_XmMMsgCascadeB_0002
 
+#define FIX_1665
 
 /********    Static Function Declarations    ********/
 
@@ -1151,6 +1147,10 @@ InputDispatch(
 
           else if (event->type == KeyPress)
              KeySelect (cb, event);
+
+#ifdef FIX_1665
+          CBG_SetWasPosted(cb, FALSE);
+#endif
       }
       /* else option menu - do nothing if menu was not posted on btndown */
    }
