@@ -22,18 +22,6 @@
  * Floor, Boston, MA 02110-1301 USA
  * 
  */
-/*
- * (c) Copyright 1996 Digital Equipment Corporation.
- * (c) Copyright 1996 Hewlett-Packard Company.
- * (c) Copyright 1996 International Business Machines Corp.
- * (c) Copyright 1996 Sun Microsystems, Inc.
- * (c) Copyright 1996 Novell, Inc. 
- * (c) Copyright 1996 FUJITSU LIMITED.
- * (c) Copyright 1996 Hitachi.
- */
-/*
- * HISTORY
- */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -62,7 +50,7 @@
 #define WARNING2	_XmMMsgColObj_0002
 
 #ifdef FIX_1400
-static void trap_XCloseDisplay(Display *disp, XExtCodes *codes);
+static int trap_XCloseDisplay(Display *disp, XExtCodes *codes);
 #endif
 
 /** default should not be killed unless application is dying **/
@@ -1543,9 +1531,10 @@ XmeGetDesktopColorCells (Screen * screen,
 }
 
 #ifdef FIX_1400
-static void trap_XCloseDisplay(Display *disp, XExtCodes *codes)
+static int trap_XCloseDisplay(Display *disp, XExtCodes *codes)
 {
     if (disp == _XmColorObjCacheDisplay)
     	_XmColorObjCacheDisplay = NULL;
+    return 0;
 }
 #endif
