@@ -20,16 +20,11 @@
  * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
  * Floor, Boston, MA 02110-1301 USA
  */ 
-/* 
- * HISTORY
-*/ 
 #ifdef REV_INFO
 #ifndef lint
 static char rcsid[] = "$TOG: Label.c /main/26 1997/06/18 17:40:00 samborn $"
 #endif
 #endif
-/* (c) Copyright 1989, DIGITAL EQUIPMENT CORPORATION, MAYNARD, MASS. */
-/* (c) Copyright 1987, 1988, 1989, 1990, 1991, 1992 HEWLETT-PACKARD COMPANY */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -1562,7 +1557,7 @@ Redisplay(
 #ifdef FIX_1505
 	      if (pix_use == Pix(lw)) {
 		  XSetFillStyle(XtDisplay(lw), gc, FillStippled);
-		  XSetStipple(XtDisplay(lw), gc, _XmGetInsensitiveStippleBitmap(lw));
+		  XSetStipple(XtDisplay(lw), gc, _XmGetInsensitiveStippleBitmap((Widget)lw));
 		  XFillRectangle(XtDisplay(lw), XtWindow(lw), gc,
 			lp->TextRect.x + lp->PixmapRect.x,
 			lp->TextRect.y + lp->PixmapRect.y,
@@ -1718,7 +1713,7 @@ Redisplay(
 		lw->primitive.shadow_thickness +
 		lp->margin_width) +
 	   lp->margin_left + lp->TextRect.width + lp->margin_right))
-
+	     {
 #ifdef FIX_1381
 		  if (XtIsSensitive(wid) )
 		  {
@@ -1756,6 +1751,7 @@ Redisplay(
 		       lp->acc_TextRect.width, XmALIGNMENT_END,
 		       XmPrim_layout_direction(lw), NULL);
 #endif
+	     }
     }
   
   /* Redraw the proper highlight  */
