@@ -20,9 +20,6 @@
  * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
  * Floor, Boston, MA 02110-1301 USA
 */ 
-/* 
- * HISTORY
-*/ 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -33,8 +30,6 @@
 static char rcsid[] = "$TOG: MenuUtil.c /main/16 1999/05/13 15:57:21 mgreess $"
 #endif
 #endif
-/* (c) Copyright 1989, DIGITAL EQUIPMENT CORPORATION, MAYNARD, MASS. */
-/* (c) Copyright 1987, 1988, 1989, 1990, 1991, 1992 HEWLETT-PACKARD COMPANY */
 
 #include <stdio.h>
 #include <ctype.h>
@@ -1053,11 +1048,7 @@ _XmMenuGrabKeyboardAndPointer(
 
    register int status =
            (_XmGrabKeyboard(widget,
-#ifdef FIX_1565
-                            False,
-#else
                             True,
-#endif
                             GrabModeSync,
                             GrabModeAsync,
                             time) != GrabSuccess);
